from flask import Flask, request, render_template
from llama_index.vector_stores.chroma import ChromaVectorStore
from llama_index.core.node_parser import SimpleNodeParser
from llama_index.core import VectorStoreIndex, SimpleDirectoryReader, StorageContext, SummaryIndex
import chromadb
import uuid
import os

os.environ['OPENAI_API_KEY'] = "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"

app = Flask(__name__)

base_dir = "/root/ai_doc/upload"


@app.route('/uploadAndLearn', methods=['GET', 'POST'])
def uploader():
    if request.method == 'POST':
        f = request.files['file']
        project_id = request.form['projectId']
        doc_id = request.form['docId']
        project_name = request.form['projectName']
        tmp_dir = base_dir + "/" + str(uuid.uuid4())
        os.makedirs(tmp_dir)
        fpath = os.path.join(tmp_dir, f.filename)
        f.save(fpath)
        store2db(tmp_dir, doc_id, project_id, project_name)
        return "success"


@app.route('/deleteFile', methods=['GET', 'POST'])
def deleteFile():
    if request.method == 'POST':
        project_id = request.form['projectId']
        doc_id = request.form['docId']
        client = chromadb.PersistentClient(path="./chroma_store_new")
        # create collection
        chroma_collection = client.get_or_create_collection(project_id)
        # assign chroma as the vector_store to the context
        vector_store = ChromaVectorStore(chroma_collection=chroma_collection)
        storage_context = StorageContext.from_defaults(vector_store=vector_store)
        index = VectorStoreIndex.from_vector_store(vector_store=vector_store, storage_context=storage_context)
        index.delete_ref_doc(doc_id, delete_from_docstore=True)
        return "success"


def store2db(data_dir, doc_id, project_id, project_name):
    client = chromadb.PersistentClient(path="./chroma_store_new")
    # create collection
    chroma_collection = client.get_or_create_collection(project_id)
    # assign chroma as the vector_store to the context
    vector_store = ChromaVectorStore(chroma_collection=chroma_collection)
    storage_context = StorageContext.from_defaults(vector_store=vector_store)

    index = VectorStoreIndex.from_vector_store(vector_store=vector_store, storage_context=storage_context)

    docs = SimpleDirectoryReader(data_dir).load_data()

    docs[0].doc_id = doc_id
    docs[0].metadata = {"project": project_id, "project_name": project_name}

    parser = SimpleNodeParser.from_defaults(chunk_size=1024, chunk_overlap=32)
    nodes = parser.get_nodes_from_documents(docs)
    index.insert_nodes(nodes)


if __name__ == '__main__':
    app.run(host='0.0.0.0', port=18081)



import pymysql


def get_db():
    """
    获取数据库连接对象
    """
    # 打开数据库连接
    db = pymysql.connect(
        host="47.91.24.169", port=3306, user="root", passwd="bjzy@2024", db="dms"
    )
    return db


def get_sql_conn():
    """
    获取数据库连接和游标对象
    """
    db = get_db()
    cursor = db.cursor()
    return db, cursor

def execute_sql(sql):
    db = get_db()
    cursor = db.cursor()

    # 执行查询
    cursor.execute(sql)

    # 获取所有结果
    rows = cursor.fetchall()

    # 将结果转换为字典列表
    results = [dict(zip(tuple(column[0] for column in cursor.description), row)) for row in rows]

    # 关闭游标和连接
    cursor.close()
    db.close()
    return results










from datetime import datetime, timedelta
import requests
from flask import request
from llama_index.core.tools import FunctionTool

app_server_url = "http://127.0.0.1:8080/business/data"

def contract_sum(begin: str, end: str) -> str:
    """通过年份获取合同金额"""
    userId = request.get_json()['userId']
    print(f"userid:{userId}")
    url = f"{app_server_url}/getContractAmountSum?startTime={begin}&endTime={end}&userId={userId}"
    print(url)
    resp = requests.get(url)
    print(resp.status_code)
    print(resp.json())
    return resp.json()


def current_year(begin: str) -> str:
    print("param begin:" + begin)
    now = datetime.now()
    start_of_year = datetime(now.year, 1, 1)
    end_of_year = datetime(now.year + 1, 1, 1) - timedelta(days=1)
    return start_of_year.strftime("%Y-%m-%d") + "," + end_of_year.strftime("%Y-%m-%d")

contract_sum = FunctionTool.from_defaults(fn=contract_sum)

current_year = FunctionTool.from_defaults(fn=current_year)


def function_tool_list():
    return [contract_sum, current_year]








from flask import Flask, request
from llama_index.core.agent import ReActAgent
from llama_index.core.base.llms.types import ChatMessage
from llama_index.core.chat_engine.types import ChatMode
from llama_index.core.tools import QueryEngineTool
from llama_index.vector_stores.chroma import ChromaVectorStore
import chromadb
from llama_index.core import StorageContext

#智普
from llama_index.core.base.embeddings.base import BaseEmbedding
from llama_index.llms.openai_like import OpenAILike
from llama_index.core import VectorStoreIndex, Settings
from zhipuai import ZhipuAI
from typing import Any, List
from pydantic import Field
import os

import importlib.abc
import importlib.util


from llama_index.core.vector_stores import (
    MetadataFilter,
    MetadataFilters,
)

app_server_url = "http://127.0.0.1:8080/business/data"
api_key = "01d2e542d5c8192cc1f5be1138cd3a72.NcbuwvFpbE8kycTu"
api_base = "https://open.bigmodel.cn/api/paas/v4"
model = "glm-4"
llm = OpenAILike(
    model=model,
    api_base=api_base,
    api_key=api_key,
    is_chat_model=True,
    is_local=False,
    is_function_calling_model=False,
)



class FileLoader(importlib.abc.Loader):
    def __init__(self, file_path):
        self.file_path = file_path

    def create_module(self, spec):
        return None

    def exec_module(self, module):
        with open(self.file_path, 'r', encoding='utf-8') as f:
            code = f.read()
        exec(code, module.__dict__)

def load_module_from_file(module_name, file_path):
    loader = FileLoader(file_path)
    spec = importlib.util.spec_from_file_location(module_name, file_path, loader=loader)
    module = importlib.util.module_from_spec(spec)
    spec.loader.exec_module(module)
    return module




class ZhipuEmbeddings(BaseEmbedding):
    client: ZhipuAI = Field(default_factory=lambda: ZhipuAI(api_key=api_key))

    def __init__(
            self,
            model_name: str = "embedding-3",
            **kwargs: Any,
    ) -> None:
        super().__init__(model_name=model_name, **kwargs)
        self.model_name = model_name

    def invoke_embedding(self, query: str) -> List[float]:
        response = self.client.embeddings.create(
            model=self.model_name, input=[query], dimensions=256
        )

        # 检查响应是否成功
        if response.data and len(response.data) > 0:
            return response.data[0].embedding
        else:
            raise ValueError("Failed to get embedding from ZhipuAI API")

    def _get_query_embedding(self, query: str) -> List[float]:
        return self.invoke_embedding(query)

    def _get_text_embedding(self, text: str) -> List[float]:
        return self.invoke_embedding(text)

    def _get_text_embeddings(self, texts: List[str]) -> List[List[float]]:
        return [self._get_text_embedding(text) for text in texts]

    async def _aget_query_embedding(self, query: str) -> List[float]:
        return self._get_query_embedding(query)

    async def _aget_text_embedding(self, text: str) -> List[float]:
        return self._get_text_embedding(text)

    async def _aget_text_embeddings(self, texts: List[str]) -> List[List[float]]:
        return self._get_text_embeddings(texts)

#os.environ['OPENAI_API_KEY'] = "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"
#llm = OpenAI(model="gpt-4o")
Settings.llm = llm
Settings.embed_model = ZhipuEmbeddings()

os.environ["TOKENIZERS_PARALLELISM"] = "false"

app = Flask(__name__)

save_collection = "project-collection"
chroma_store_path = "./chroma_store_new11"
@app.route('/chat', methods=['GET', 'POST'])
def chat():
    json = request.get_json()
    text = json['msg']
    project_id = None
    history = None
    if 'history' in json:
        history = json['history']
    if 'project_id' in json:
        project_id = json['project_id']

    query_engine = init_query_engine(project_id)
    #query_engine = init_chat_engine(project_id)
    return response(text, history, query_engine)

def init_query_engine(project_id):
    index = getIndex()
    filters = MetadataFilters(
        filters=[
            MetadataFilter(key="project", value=project_id),
        ],
    )
    query_engine = index.as_query_engine(similarity_top_k=5, filters=filters if project_id is not None else None, response_mode='tree_summarize')
    return query_engine

def init_chat_engine(project_id):
    index = getIndex()
    filters = MetadataFilters(
        filters=[
            MetadataFilter(key="project", value=project_id),
        ],
    )
    from llama_index.core.memory import ChatMemoryBuffer
    memory = ChatMemoryBuffer.from_defaults(token_limit=3900)
    chat_engine = index.as_chat_engine(
        chat_mode=ChatMode.CONDENSE_PLUS_CONTEXT,
        memory=memory,
        llm=llm,
        filters=filters if project_id is not None else None,
        context_prompt=(
            "You are a chatbot, able to have normal interactions, as well as talk"
            " about an essay discussing contract information."
            "Here are the relevant documents for the context:\n"
            "{context_str}"
            "\nInstruction: Use the previous chat history, or the context above, to interact and help the user."
        ),
        verbose=True,
    )
    return chat_engine


def response(msg, history, chat_engine):
    chat_history = []
    for item in history:
        chat_history.append(ChatMessage(
            role="user",
            content=item
        ))
    chat_history.append(ChatMessage(content = "以上是历史聊天消息", role="user"))

    doc_tool = QueryEngineTool.from_defaults(
        chat_engine,
        name="doc",
        description="用于查询合同的基本信息",
    )

    module_path = "/home/plugins/ToolPlugin.py"
    module_name = "ToolPlugin"
    plugin_module = load_module_from_file(module_name, module_path)
    function_tools = plugin_module.function_tool_list()
    function_tools.append(doc_tool)
    agent = ReActAgent.from_tools(function_tools, llm=llm, verbose=True, chat_history= chat_history)

    res = agent.chat(
        message=msg
    )
    #res = chat_engine.chat(msg, chat_history=chat_history)
    print(res.response)
    agent.reset()
    return res.response



def getIndex():
    client = chromadb.PersistentClient(path=chroma_store_path)
    # create collection
    chroma_collection = client.get_or_create_collection(save_collection)
    # assign chroma as the vector_store to the context
    vector_store = ChromaVectorStore(chroma_collection=chroma_collection)
    storage_context = StorageContext.from_defaults(vector_store=vector_store)
    index = VectorStoreIndex.from_vector_store(
        vector_store, storage_context=storage_context
    )
    return index



if __name__ == '__main__':
    app.run(host='0.0.0.0', port=18081)



from flask import Flask, request, render_template
from llama_index.vector_stores.chroma import ChromaVectorStore
from llama_index.core.node_parser import SimpleNodeParser
from llama_index.core import VectorStoreIndex, SimpleDirectoryReader, StorageContext, SummaryIndex
import chromadb
import uuid
import multiprocessing

#os.environ['OPENAI_API_KEY'] = "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"

#智普
from llama_index.core.base.embeddings.base import BaseEmbedding
from llama_index.llms.openai_like import OpenAILike
from llama_index.core import Settings
from llama_index.core import VectorStoreIndex, SimpleDirectoryReader, Settings
from llama_index.core import SimpleDirectoryReader, SummaryIndex
from zhipuai import ZhipuAI
from typing import Any, List
from pydantic import Field
import os
from datetime import datetime


api_key = "01d2e542d5c8192cc1f5be1138cd3a72.NcbuwvFpbE8kycTu"
api_base = "https://open.bigmodel.cn/api/paas/v4"
model = "glm-4"
llm = OpenAILike(
    model=model,
    api_base=api_base,
    api_key=api_key,
    is_chat_model=True,
    is_local=False,
    is_function_calling_model=False,
)


class ZhipuEmbeddings(BaseEmbedding):
    client: ZhipuAI = Field(default_factory=lambda: ZhipuAI(api_key=api_key))

    def __init__(
            self,
            model_name: str = "embedding-3",
            **kwargs: Any,
    ) -> None:
        super().__init__(model_name=model_name, **kwargs)
        self.model_name = model_name

    def invoke_embedding(self, query: str) -> List[float]:
        response = self.client.embeddings.create(
            model=self.model_name, input=[query], dimensions=256
        )

        # 检查响应是否成功
        if response.data and len(response.data) > 0:
            return response.data[0].embedding
        else:
            raise ValueError("Failed to get embedding from ZhipuAI API")

    def _get_query_embedding(self, query: str) -> List[float]:
        return self.invoke_embedding(query)

    def _get_text_embedding(self, text: str) -> List[float]:
        return self.invoke_embedding(text)

    def _get_text_embeddings(self, texts: List[str]) -> List[List[float]]:
        return [self._get_text_embedding(text) for text in texts]

    async def _aget_query_embedding(self, query: str) -> List[float]:
        return self._get_query_embedding(query)

    async def _aget_text_embedding(self, text: str) -> List[float]:
        return self._get_text_embedding(text)

    async def _aget_text_embeddings(self, texts: List[str]) -> List[List[float]]:
        return self._get_text_embeddings(texts)


Settings.llm = llm
Settings.embed_model = ZhipuEmbeddings()

os.environ["TOKENIZERS_PARALLELISM"] = "false"

app = Flask(__name__)

base_dir = "/root/ai_doc/upload"
save_collection = "project-collection"
chroma_store_path = "./chroma_store_new11"

@app.route('/uploadAndLearn', methods=['GET', 'POST'])
def uploader():
    if request.method == 'POST':
        f = request.files['file']
        format = request.form['format']
        tmp_dir = base_dir + "/" + str(uuid.uuid4())
        os.makedirs(tmp_dir)
        fpath = os.path.join(tmp_dir, f.filename)
        f.save(fpath)
        return multiprocessDigiest(tmp_dir, format)

@app.route('/uploadToVectorStore', methods=['GET', 'POST'])
def vectorStore():
    if request.method == 'POST':
        f = request.files['file']
        project_id = request.form['projectId']
        doc_id = request.form['docId']
        project_name = request.form['projectName']
        tmp_dir = base_dir + "/" + str(uuid.uuid4())
        os.makedirs(tmp_dir)
        fpath = os.path.join(tmp_dir, f.filename)
        f.save(fpath)
        store2db(tmp_dir, doc_id, project_id, project_name)
        return "save to vector store success"

def digiest(data_dir, format):
    docs = SimpleDirectoryReader(data_dir).load_data()
    index = SummaryIndex.from_documents(docs)
    query_engine = index.as_query_engine(response_mode="compact")
    response = query_engine.query("请用标准的json格式列出合同的名称、内容、金额、甲方、乙方、违约条款、合同开始时间（标准时间格式）、合同结束时间（标准时间格式）、委托方联系人、委托方联系方式、委托方通讯地址") if format == 'json' \
        else query_engine.query("请列出合同的名称、金额、甲方、乙方、违约条款、合同开始时间（标准时间格式）、合同结束时间（标准时间格式）、内容、委托方联系人、委托方联系方式、委托方通讯地址，输出每一项结果，以换行分割,禁止空白行")
    print(response)
    return response.response

def multiprocessDigiest(data_dir, format):
    manager = multiprocessing.Manager()
    shared_dic = manager.dict()
    questions = ["合同的委托方是谁,请不要回答其他内容。举例如下： {'contractPartyA':'字节跳动'}",
                 "合同的名称是什么,请不要回答其他内容。举例如下： {'contractName':'开发委托合同'}",
                 "合同的被委托方是谁,请不要回答其他内容。举例如下： {'contractPartyB':'腾讯集团'}",
                 "合同的金额是多少,请不要回答其他内容。举例如下： {'amount':200}",
                 "合同的违约条款是什么,请不要回答其他内容。举例如下： {'defaultClause':'需支付违约金100万元'}",
                 "合同的服务内容是什么,请不要回答其他内容。举例如下： {'contractContent':'内容包含移动端等开发设计'}",
                 "合同履行的起始结束时间是什么,请不要回答其他内容。举例如下： {'start': '2024-10-11', 'end':'2024-10-30'}",
                 "合同的委托方联系人是谁,请不要回答其他内容。举例如下： {'contactPerson':'张三'}",
                 "合同委托方联系电话是什么,请不要回答其他内容。举例如下： {'phone':'18566665656'}",
                 "合同委托方通讯地址是什么,请不要回答其他内容。举例如下： {'address':'广州天河岗顶302号'}",
                 "合同委托方邮箱是什么,请不要回答其他内容。举例如下： {'email':'contract@163.com'}"]
    processes = []
    for question in questions:
        process = multiprocessing.Process(target=useAI, args=(data_dir, question, shared_dic))
        processes.append(process)
    for process in processes:
        process.start()
    for process in processes:
        process.join()

    print("所有进程执行完毕")
    print(str(shared_dic))
    return str(shared_dic)

def useAI(data_dir,question, shared_dic):
    docs = SimpleDirectoryReader(data_dir).load_data()
    index = SummaryIndex.from_documents(docs)
    query_engine = index.as_query_engine()
    response = query_engine.query(question)
    print(response.response)
    #shared_dic[question] = response.response
    tempDict = eval(response.response)
    shared_dic.update(tempDict)
    #print("----------" + question +  ":\n" + shared_dic[question])


@app.route('/deleteFile', methods=['GET', 'POST'])
def deleteFile():
    if request.method == 'POST':
        doc_ids = request.form['docIds']
        idlist = doc_ids.split(",")
        for doc_id in idlist:
            client = chromadb.PersistentClient(path=chroma_store_path)
            # create collection
            chroma_collection = client.get_or_create_collection(save_collection)
            # assign chroma as the vector_store to the context
            vector_store = ChromaVectorStore(chroma_collection=chroma_collection)
            storage_context = StorageContext.from_defaults(vector_store=vector_store)
            index = VectorStoreIndex.from_vector_store(vector_store=vector_store, storage_context=storage_context)
            index.delete_ref_doc(doc_id, delete_from_docstore=True)
        return "success"


def store2db(data_dir, doc_id, project_id, project_name):
    client = chromadb.PersistentClient(path=chroma_store_path)
    # create collection
    chroma_collection = client.get_or_create_collection(save_collection)
    # assign chroma as the vector_store to the context
    vector_store = ChromaVectorStore(chroma_collection=chroma_collection)
    storage_context = StorageContext.from_defaults(vector_store=vector_store)

    index = VectorStoreIndex.from_vector_store(vector_store=vector_store, storage_context=storage_context)

    docs = SimpleDirectoryReader(data_dir).load_data()

    docs[0].id_ = doc_id
    print(docs[0].id_)


    current_time = datetime.now()  # 获取当前时间
    current_time_str = current_time.strftime("%Y-%m-%d")  # 格式化时间为字符串
    print(current_time_str)
    docs[0].metadata = {"project": project_id, "project_name": project_name, "date": current_time_str}

    parser = SimpleNodeParser.from_defaults(chunk_size=1024, chunk_overlap=32)
    nodes = parser.get_nodes_from_documents(docs)
    index.insert_nodes(nodes)




if __name__ == '__main__':
    app.run(host='0.0.0.0', port=18082)



from llama_index.core.base.embeddings.base import BaseEmbedding
from llama_index.llms.openai_like import OpenAILike
from llama_index.core import Settings
from llama_index.core import VectorStoreIndex, SimpleDirectoryReader, Settings
from llama_index.core import SimpleDirectoryReader, SummaryIndex
from zhipuai import ZhipuAI
from typing import Any, List
from pydantic import Field
import os
from llama_index.core.tools import FunctionTool, QueryEngineTool
from llama_index.llms.openai import OpenAI
from llama_index.core.agent import ReActAgent

api_key = "01d2e542d5c8192cc1f5be1138cd3a72.NcbuwvFpbE8kycTu"
api_base = "https://open.bigmodel.cn/api/paas/v4"
api_base = "https://open.bigmodel.cn/api/paas/v4"
model = "glm-4"
llm = OpenAILike(
    model=model,
    api_base=api_base,
    api_key=api_key,
    is_chat_model=True,
    is_local=False,
    is_function_calling_model=False,
)


class ZhipuEmbeddings(BaseEmbedding):
    client: ZhipuAI = Field(default_factory=lambda: ZhipuAI(api_key=api_key))

    def __init__(
            self,
            model_name: str = "embedding-3",
            **kwargs: Any,
    ) -> None:
        super().__init__(model_name=model_name, **kwargs)
        self.model_name = model_name

    def invoke_embedding(self, query: str) -> List[float]:
        response = self.client.embeddings.create(
            model=self.model_name, input=[query], dimensions=256
        )

        # 检查响应是否成功
        if response.data and len(response.data) > 0:
            return response.data[0].embedding
        else:
            raise ValueError("Failed to get embedding from ZhipuAI API")

    def _get_query_embedding(self, query: str) -> List[float]:
        return self.invoke_embedding(query)

    def _get_text_embedding(self, text: str) -> List[float]:
        return self.invoke_embedding(text)

    def _get_text_embeddings(self, texts: List[str]) -> List[List[float]]:
        return [self._get_text_embedding(text) for text in texts]

    async def _aget_query_embedding(self, query: str) -> List[float]:
        return self._get_query_embedding(query)

    async def _aget_text_embedding(self, text: str) -> List[float]:
        return self._get_text_embedding(text)

    async def _aget_text_embeddings(self, texts: List[str]) -> List[List[float]]:
        return self._get_text_embeddings(texts)


Settings.llm = llm
Settings.embed_model = ZhipuEmbeddings()

os.environ["TOKENIZERS_PARALLELISM"] = "false"




# define sample Tool

documents = SimpleDirectoryReader("../data").load_data()
index = SummaryIndex.from_documents(documents)
query_engine = index.as_query_engine()

my_query_tool = QueryEngineTool.from_defaults(
    query_engine,
    name="技术开发合同",
    description="技术开发合同的基本信息",
)
def Approval_status(
        contract: str =Field(
            description="合同的名称"
        ),
        oper_type: str =Field(
            description="业务类型，比如审核、付款等"
        ),
) -> str:
    """用于查询合同业务审批或付款情况"""
    print("获得参数contract:"+contract+ " 业务类型:"+ oper_type)
    return "已完成审批"


def contract_sum(begin: str,  end: str) -> str:
    """用于统计指定的起始时间到截止时间的合同金额"""
    print("获得参数begin:"+begin+"  end:"+end)
    return {"ret:'success',data:'100'"}


def current_year(begin: str) -> str:
    """用于将'今年'转变成当前时间"""
    print("获得参数begin:"+begin)
    return "2024年1月1到2024年12月31日"




contract_sum = FunctionTool.from_defaults(fn=contract_sum)

current_year = FunctionTool.from_defaults(fn=current_year)

Approval_status = FunctionTool.from_defaults(fn=Approval_status)


# initialize ReAct agent
agent = ReActAgent.from_tools([current_year, contract_sum, Approval_status, my_query_tool], llm=llm, verbose=True)

response = agent.chat("维保合同的审批情况怎么样了")
print(response)

#response = agent.chat("技术开发合同的甲方是谁")
#print(response)





from llama_index.core.base.embeddings.base import BaseEmbedding
from llama_index.llms.openai_like import OpenAILike
from llama_index.core import Settings
from llama_index.core import VectorStoreIndex, SimpleDirectoryReader, Settings
from llama_index.core import SimpleDirectoryReader, SummaryIndex
from zhipuai import ZhipuAI
from typing import Any, List
from pydantic import Field
import os

api_key = "01d2e542d5c8192cc1f5be1138cd3a72.NcbuwvFpbE8kycTu"
api_base = "https://open.bigmodel.cn/api/paas/v4"
api_base = "https://open.bigmodel.cn/api/paas/v4"
model = "glm-4"
llm = OpenAILike(
    model=model,
    api_base=api_base,
    api_key=api_key,
    is_chat_model=True,
    is_local=False,
    is_function_calling_model=False,
)


class ZhipuEmbeddings(BaseEmbedding):
    client: ZhipuAI = Field(default_factory=lambda: ZhipuAI(api_key=api_key))

    def __init__(
            self,
            model_name: str = "embedding-3",
            **kwargs: Any,
    ) -> None:
        super().__init__(model_name=model_name, **kwargs)
        self.model_name = model_name

    def invoke_embedding(self, query: str) -> List[float]:
        response = self.client.embeddings.create(
            model=self.model_name, input=[query], dimensions=256
        )

        # 检查响应是否成功
        if response.data and len(response.data) > 0:
            return response.data[0].embedding
        else:
            raise ValueError("Failed to get embedding from ZhipuAI API")

    def _get_query_embedding(self, query: str) -> List[float]:
        return self.invoke_embedding(query)

    def _get_text_embedding(self, text: str) -> List[float]:
        return self.invoke_embedding(text)

    def _get_text_embeddings(self, texts: List[str]) -> List[List[float]]:
        return [self._get_text_embedding(text) for text in texts]

    async def _aget_query_embedding(self, query: str) -> List[float]:
        return self._get_query_embedding(query)

    async def _aget_text_embedding(self, text: str) -> List[float]:
        return self._get_text_embedding(text)

    async def _aget_text_embeddings(self, texts: List[str]) -> List[List[float]]:
        return self._get_text_embeddings(texts)


Settings.llm = llm
Settings.embed_model = ZhipuEmbeddings()

os.environ["TOKENIZERS_PARALLELISM"] = "false"

documents = SimpleDirectoryReader("../data").load_data()
index = SummaryIndex.from_documents(documents)
query_engine = index.as_query_engine()
response = query_engine.query(
    "请用json的格式列出互联网数据分布式抓取平台技术服务合同的金额、名称、甲方、乙方、违约条款、合同期限")
print(response)






from setuptools import setup, find_packages

setup(
    name='smartarchive',
    version='0.1',
    description='A simple Python library of ai doc manage',
    author='bjzy',
    author_email='your_email@example.com',
    packages=find_packages(),
    python_requires='>=3.11',
    install_requires=[],
)